<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>LXQtNetworkMonitor</name>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="159"/>
        <source>Network interface &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Verkkoliitäntä &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="160"/>
        <source>Transmitted %1</source>
        <translation>Siirretty %1</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="161"/>
        <source>Received %1</source>
        <translation>Vastaanotettu %1</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="206"/>
        <source>B</source>
        <translation>t</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="207"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="207"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="207"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="207"/>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="207"/>
        <source>PiB</source>
        <translation>PiB</translation>
    </message>
</context>
<context>
    <name>LXQtNetworkMonitorConfiguration</name>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="14"/>
        <source>Network Monitor Settings</source>
        <translation>Verkkoseurannan astukset</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Yleiset</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="35"/>
        <source>Interface</source>
        <translation>Liitäntä</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="56"/>
        <source>Modem</source>
        <translation>Modeemi</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="65"/>
        <source>Monitor</source>
        <translation>Monitori</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="74"/>
        <source>Network</source>
        <translation>Verkko</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="83"/>
        <source>Wireless</source>
        <translation>Langaton</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="95"/>
        <source>Icon</source>
        <translation>Kuvake</translation>
    </message>
</context>
</TS>
